Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > Member List

This is the complete list of members for ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >, including all inherited members.

equal(set_intersection_cursor const &that) const (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
equal(default_sentinel) const (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
move() const noexcept(noexcept(decltype(iter_move(it1_))(iter_move(it1_)))) -> decltype(iter_move(it1_)) (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
next() (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
read() const noexcept(noexcept(decltype(*it1_)(*it1_))) -> decltype(*it1_) (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
set_intersection_cursor()=default (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
set_intersection_cursor(pred_ref_ pred, proj1_ref_ proj1, proj2_ref_ proj2, iterator_t< R1 > it1, sentinel_t< R1 > end1, iterator_t< R2 > it2, sentinel_t< R2 > end2) (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
single_pass typedef (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |
value_type typedef (defined in ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >) | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 > |